==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Сбросить',
	'boxstr_close' => 'Закрыть',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Следующий',
	'boxstr_previous' => 'Предыдущий',
	'boxstr_slideshowStart' => 'Просмотр изображений',
	'boxstr_slideshowStop' => 'Остановить',
	'boxstr_zoom' => 'Масштаб',

	// E
	'explication_selecteur' => 'Укажите элемент, который вызовет окно. (JQuery или CSS)',
	'explication_selecteur_galerie' => 'Выберите элементы, которые нужно сгруппировать в галерее. (jQuery или CSS)',
	'explication_splash_url' => 'Укажите URL к медиа файлу, который будет отображаться в сплывающем окне при первом входе на сайт.',
	'explication_traiter_toutes_images' => 'Вставить рамку вокруг всех изображений?',

	// L
	'label_active' => 'Включить медиабокс на сайте',
	'label_apparence' => 'Внешний вид',
	'label_aucun_style' => 'Не использовать рамку по умолчанию',
	'label_choix_transition_elastic' => 'Плавно',
	'label_choix_transition_fade' => 'Тень',
	'label_choix_transition_none' => 'Без переходных эффектов',
	'label_maxheight' => 'Макс. высота (% или px)',
	'label_maxwidth' => 'Макс. ширина (% или px)',
	'label_minheight' => 'Мин. высота (% или px)',
	'label_minwidth' => 'Мин. ширина (% или px)',
	'label_opacite' => 'Прозрачность фона',
	'label_selecteur_commun' => 'В общем',
	'label_selecteur_galerie' => 'Режим  галереи ',
	'label_skin' => 'Шаблон для вывода',
	'label_slideshow_speed' => 'Время демонстрации картинки  в слайдоу (ms)',
	'label_speed' => 'Скорость смены кадров (ms)',
	'label_splash' => 'Всплывающее Окно',
	'label_splash_url' => 'Ссылка для просмотра',
	'label_traiter_toutes_images' => 'Изображения',
	'label_transition' => 'Смена изображений',

	// T
	'titre_menu_box' => 'Медиабокс',
	'titre_page_configurer_box' => 'Настройки Медиабокса'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Сбросить',
	'boxstr_close' => 'Закрыть',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Следующий',
	'boxstr_previous' => 'Предыдущий',
	'boxstr_slideshowStart' => 'Просмотр изображений',
	'boxstr_slideshowStop' => 'Остановить',
	'boxstr_zoom' => 'Масштаб',

	// E
	'explication_selecteur' => 'Укажите элемент, который вызовет окно. (JQuery или CSS)',
	'explication_selecteur_galerie' => 'Выберите элементы, которые нужно сгруппировать в галерее. (jQuery или CSS)',
	'explication_splash_url' => 'Укажите URL к медиа файлу, который будет отображаться во всплывающем окне при первом входе на сайт.',
	'explication_traiter_toutes_images' => 'Вставить рамку вокруг всех изображений?',

	// L
	'label_active' => 'Включить медиабокс на сайте',
	'label_apparence' => 'Внешний вид',
	'label_aucun_style' => 'Не использовать рамку по умолчанию',
	'label_choix_transition_elastic' => 'Плавно',
	'label_choix_transition_fade' => 'Тень',
	'label_choix_transition_none' => 'Без переходных эффектов',
	'label_maxheight' => 'Макс. высота (% или px)',
	'label_maxwidth' => 'Макс. ширина (% или px)',
	'label_minheight' => 'Мин. высота (% или px)',
	'label_minwidth' => 'Мин. ширина (% или px)',
	'label_opacite' => 'Прозрачность фона',
	'label_selecteur_commun' => 'В общем',
	'label_selecteur_galerie' => 'Режим  галереи ',
	'label_skin' => 'Шаблон для вывода',
	'label_slideshow_speed' => 'Время демонстрации картинки  в слайдоу (ms)',
	'label_speed' => 'Скорость смены кадров (ms)',
	'label_splash' => 'Всплывающее Окно',
	'label_splash_height' => 'Высота (% или px)',
	'label_splash_url' => 'Ссылка для просмотра',
	'label_splash_width' => 'Ширина (% или px)',
	'label_traiter_toutes_images' => 'Изображения',
	'label_transition' => 'Смена изображений',

	// T
	'titre_menu_box' => 'Медиабокс',
	'titre_page_configurer_box' => 'Настройки Медиабокса'
);

?>
